#include "scene.h"

#include <QGraphicsSceneMouseEvent>
#include <QGraphicsPixmapItem>
#include <QGraphicsRectItem>
#include <QDebug>


SceneSheme::SceneSheme(QObject* parent) : QGraphicsScene(parent)
{
    m_colorSelectionPen = new QColor(158,182,255,200);
    m_colorSelectionBrush = new QColor(158,182,255,96);

}

void SceneSheme::mousePressEvent(QGraphicsSceneMouseEvent* event)
{
    if (event->button() & Qt::LeftButton)
    {
        // При зажатой левой кнопки мыши, запоминаем позицию
        m_leftMouseButtonPressed = true;
        setPreviousPosition(event->scenePos());

        m_AreaSelection = new AreaSelector(QRectF(0,0,0.0001,0.0001));

        addItem(m_AreaSelection);
    }

    QGraphicsScene::mousePressEvent(event);
    qDebug()<<"click";
}

void SceneSheme::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
{
    if (m_leftMouseButtonPressed)
    {
        update();
        // формируем область выделения при движениюю мышью при зажатой ЛКМ
        auto dx = event->scenePos().x() - m_previousPosition.x();
        auto dy = event->scenePos().y() - m_previousPosition.y();
        m_AreaSelection->setSelectedArea(QRectF((dx > 0) ? m_previousPosition.x() : m_previousPosition.x() - qAbs(dx),
                                                (dy > 0) ? m_previousPosition.y() : m_previousPosition.y() - qAbs(dy),
                                                qAbs(dx),
                                                qAbs(dy)));
        qDebug()<<"move";
    }
    QGraphicsScene::mouseMoveEvent(event);

}

void SceneSheme::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
{
    if (event->button() & Qt::LeftButton)
    {
        m_leftMouseButtonPressed = false;

    update();
    }
    QGraphicsScene::mouseReleaseEvent(event);
}

void SceneSheme::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
{
    qDebug()<<"doubleclick";
    QGraphicsScene::mouseDoubleClickEvent(event);
}

void SceneSheme::setPreviousPosition(const QPointF previousPosition)
{
    if (m_previousPosition == previousPosition)
        return;

    m_previousPosition = previousPosition;
    emit previousPositionChanged(m_previousPosition);
}

QPointF SceneSheme::previousPosition() const
{
    return m_previousPosition;
}
